# namekoplus

[![Upload Python Package](https://github.com/Bryanthelol/namekoplus/actions/workflows/python-publish.yml/badge.svg?event=release)](https://github.com/Bryanthelol/namekoplus/actions/workflows/python-publish.yml)

A lightweight Python distributed microservice solution

## CLI Usage

### Checkout Command

```shell
namekoplus --help
```

### Start a middleware that nameko depends on

```shell
namekoplus start -m rabbitmq
```

### Initialize a nameko service from templates

```shell
namekoplus init --directory <dir_name> --type <template_type>
```


## Detailed Usage

See Documents: 

- [English](https://murl.vip/TwML)
- [中文](https://murl.vip/B0O9)